@@ -9,9 +9,9 @@ _J='st'
 _I='suite_setup'
 _H='force_tags'
 _G='type'
-_F=None
-_E='suite_teardown'
-_D='__st__.py'
+_F='suite_teardown'
+_E='__st__.py'
+_D=None
 _C=False
 _B=True
 _A='cases'
@@ -22,11 +22,11 @@ def tagmatch(pattern):
 		if fnmatch.fnmatch(tag,pattern):return _B
 	return _C
 class Collector:
-	SUITE_TAGS=[_H,_M];SUITE_STS=[_I,_E,_N,_O];exec_list=[];exec_table={};case_number=0;suite_tag_table={_H:{},_M:{}};current_case_tags=[]
+	SUITE_TAGS=[_H,_M];SUITE_STS=[_I,_F,_N,_O];exec_list=[];exec_table={};case_number=0;suite_tag_table={_H:{},_M:{}};current_case_tags=[]
 	@classmethod
-	def run(cls,casedir=_A,suitename_filters=[],casename_filters=[],tag_include_expr=_F,tag_exclude_expr=_F):
+	def run(cls,casedir=_A,suitename_filters=[],casename_filters=[],tag_include_expr=_D,tag_exclude_expr=_D):
 		for (dirpath,dirnames,filenames) in os.walk(casedir):
-			if _D in filenames:filenames.remove(_D);filenames.insert(0,_D)
+			if _E in filenames:filenames.remove(_E);filenames.insert(0,_E)
 			for fn in filenames:
 				filepath=os.path.join(dirpath,fn)
 				if not filepath.endswith(_P):continue
@@ -42,8 +42,8 @@ class Collector:
 			if not valid:cls.exec_list.remove(stPath);cls.exec_table.pop(stPath)
 	@classmethod
 	def handleOneModule(cls,module,filepath,tag_include_expr,tag_exclude_expr,suitename_filters,casename_filters):
-		stType=filepath.endswith(_D);caseType=not stType
-		if stType:filepath=filepath.replace(_D,'')
+		stType=filepath.endswith(_E);caseType=not stType
+		if stType:filepath=filepath.replace(_E,'')
 		meta={_G:_Q if caseType else _J}
 		if caseType:meta[_A]=[]
 		for (name,item) in module.__dict__.items():
@@ -95,13 +95,13 @@ class Collector:
 				if fnmatch.fnmatch(name,pattern):return _B
 		return _C
 class Runner:
-	case_list=[]
+	curRunningCase=_D;case_list=[]
 	@classmethod
 	def run(cls):
 		if not Collector.exec_list:signal.criticalInfo('没有可以执行的测试用例');return 2
 		cls.caseId=0
 		for (name,meta) in Collector.exec_table.items():
-			if meta[_G]==_J and _E in meta:cls._insertTeardownToExecList(name)
+			if meta[_G]==_J and _F in meta:cls._insertTeardownToExecList(name)
 		signal.test_start();cls.execTest();signal.test_end(cls);from hytest.common import GSTORE;return GSTORE.get('---ret---',3)
 	@classmethod
 	def execTest(cls):
@@ -112,7 +112,7 @@ class Runner:
 				if name.startswith(suite_setup_failed):affected=_B;break
 			if affected:continue
 			if name.endswith(_L):
-				name=name.replace(_L,'');suite_teardown=Collector.exec_table[name][_E];signal.teardown(name,A)
+				name=name.replace(_L,'');suite_teardown=Collector.exec_table[name][_F];signal.teardown(name,A)
 				try:suite_teardown()
 				except Exception as e:signal.teardown_fail(name,A,e,traceback.format_exc())
 			else:
@@ -129,7 +129,7 @@ class Runner:
 						signal.setup(name,A)
 						try:suite_setup()
 						except Exception as e:signal.setup_fail(name,A,e,traceback.format_exc());continue
-					cls._exec_cases(meta);suite_teardown=meta.get(_E)
+					cls._exec_cases(meta);suite_teardown=meta.get(_F)
 					if suite_teardown:
 						signal.teardown(name,A)
 						try:suite_teardown()
@@ -149,7 +149,7 @@ class Runner:
 	def _exec_cases(cls,meta):
 		B='case_default';A='case';test_setup=meta.get(_N);test_teardown=meta.get(_O)
 		for case in meta[_A]:
-			cls.case_list.append(case);case_className=type(case).__name__;cls.caseId+=1;signal.enter_case(cls.caseId,case.name,case_className);caseSetup=getattr(case,'setup',_F)
+			cls.case_list.append(case);case_className=type(case).__name__;cls.caseId+=1;signal.enter_case(cls.caseId,case.name,case_className);cls.curRunningCase=case;caseSetup=getattr(case,'setup',_D)
 			if caseSetup:
 				signal.setup(case.name,A)
 				try:caseSetup()
@@ -159,10 +159,10 @@ class Runner:
 				try:test_setup()
 				except Exception as e:signal.setup_fail(case.name,B,e,traceback.format_exc());continue
 			signal.case_steps(case.name)
-			try:case.teststeps();case.execRet='pass';signal.case_result(case)
+			try:case.execRet='pass';case.teststeps();signal.case_result(case)
 			except AssertionError as e:case.execRet='fail';case.error=e;case.stacktrace=traceback.format_exc();signal.case_result(case)
 			except Exception as e:case.execRet='abort';case.error=e;case.stacktrace=traceback.format_exc();signal.case_result(case)
-			caseTeardown=getattr(case,'teardown',_F)
+			caseTeardown=getattr(case,'teardown',_D)
 			if caseTeardown:
 				signal.teardown(case.name,A)
 				try:caseTeardown()
